@@ -4,7 +4,6 @@
  * Original author: Brane F. Gracnar
  */
 
-#include <assert.h>
 #include <stdio.h>
 #include <string.h>
 #include <errno.h>
@@ -13,7 +12,6 @@
 #include <ctype.h>
 #include <unistd.h>
 #include <getopt.h>
-#include <libgen.h>
 #include <sys/types.h>
 #include <pwd.h>
 #include <grp.h>
@@ -23,9 +21,7 @@
 #include "config.h"
 #include "miniobj.h"
 #include "configuration.h"
-
-#define AZ(foo)		do { assert((foo) == 0); } while (0)
-#define AN(foo)		do { assert((foo) != 0); } while (0)
+#include "vas.h"
 
 #define ADDR_LEN 150
 #define PORT_LEN 6
@@ -904,8 +900,13 @@ config_disp_log_facility (int facility)
 }
 
 void
-config_print_usage_fd(char *prog, hitch_config *cfg, FILE *out)
+config_print_usage_fd(char *prog, FILE *out)
 {
+	hitch_config *cfg;
+
+	cfg = config_new();
+	AN(cfg);
+
 	if (out == NULL)
 		out = stderr;
 	fprintf(out, "Usage: %s [OPTIONS] PEM\n\n", basename(prog));
@@ -991,12 +992,14 @@ config_print_usage_fd(char *prog, hitch_config *cfg, FILE *out)
 	fprintf(out, "  -p  --pidfile=FILE         PID file\n");
 	fprintf(out, "  -V  --version              Print program version and exit\n");
 	fprintf(out, "  -h  --help                 This help message\n");
+
+	config_destroy(cfg);
 }
 
 void
-config_print_usage(char *prog, hitch_config *cfg)
+config_print_usage(char *prog)
 {
-	config_print_usage_fd(prog, cfg, stdout);
+	config_print_usage_fd(prog, stdout);
 }
 
 int
@@ -1050,7 +1053,7 @@ config_parse_cli(int argc, char **argv, hitch_config *cfg, int *retval)
 	};
 
 	if (argc == 1) {
-		config_print_usage(argv[0], cfg);
+		config_print_usage(argv[0]);
 		*retval = 0;
 		return (1);
 	}
@@ -1142,7 +1145,7 @@ config_parse_cli(int argc, char **argv, hitch_config *cfg, int *retval)
 			return (1);
 			break;
 		case 'h':
-			config_print_usage(argv[0], cfg);
+			config_print_usage(argv[0]);
 			*retval = 0;
 			return (1);
 			break;
