@@ -37,6 +37,7 @@
 
 #include "config.h"
 
+#include <libgen.h>
 #include <sys/types.h>
 #include <sys/ioctl.h>
 #include <sys/socket.h>
@@ -49,7 +50,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <assert.h>
 #include <unistd.h>
 #include <fcntl.h>
 #include <errno.h>
@@ -82,6 +82,7 @@
 #include "miniobj.h"
 #include "shctx.h"
 #include "vpf.h"
+#include "vas.h"
 #include "configuration.h"
 
 #ifndef MSG_NOSIGNAL
@@ -182,8 +183,6 @@ struct addrinfo *shcupd_peers[MAX_SHCUPD_PEERS+1];
 static unsigned char shared_secret[SHA_DIGEST_LENGTH];
 #endif /*USE_SHARED_CACHE*/
 
-#define AZ(foo)		do { assert((foo) == 0); } while (0)
-#define AN(foo)		do { assert((foo) != 0); } while (0)
 #define NULL_DEV "/dev/null"
 
 int create_workers;
@@ -489,7 +488,7 @@ init_dh(SSL_CTX *ctx, const char *cert)
 	DH *dh;
 	BIO *bio;
 
-	assert(cert);
+	AN(cert);
 
 	bio = BIO_new_file(cert, "r");
 	if (!bio) {
@@ -1138,7 +1137,7 @@ init_openssl(void)
 	SSL_library_init();
 	SSL_load_error_strings();
 
-	assert(CONFIG->CERT_DEFAULT != NULL);
+	AN(CONFIG->CERT_DEFAULT);
 
 	/* The last file listed in config is the "default" cert */
 	default_ctx = make_ctx(CONFIG->CERT_DEFAULT);
@@ -1732,12 +1731,12 @@ write_proxy_v1(proxystate *ps, const struct sockaddr *local, socklen_t slen)
 	p = ringbuffer_write_ptr(&ps->ring_ssl2clear);
 	n = getnameinfo(local, slen, dst_addr, sizeof dst_addr, dst_port,
 	    sizeof dst_port, NI_NUMERICHOST | NI_NUMERICSERV);
-	assert (n == 0);
+	AZ(n);
 
 	n = getnameinfo((struct sockaddr *) &ps->remote_ip, slen, src_addr,
 	    sizeof src_addr, src_port, sizeof src_port,
 	    NI_NUMERICHOST | NI_NUMERICSERV);
-	assert (n == 0);
+	AZ(n);
 
 	if (local->sa_family == AF_INET) {
 		len = sprintf(p, "PROXY TCP4 %s %s %s %s\r\n", src_addr,
@@ -2093,7 +2092,8 @@ handle_accept(struct ev_loop *loop, ev_io *w, int revents)
 	socklen_t sl = sizeof(addr);
 
 #if HAVE_ACCEPT4==1
-	int client = accept4(w->fd, (struct sockaddr *) &addr, &sl, SOCK_NONBLOCK);
+	int client = accept4(w->fd, (struct sockaddr *) &addr, &sl,
+	    SOCK_NONBLOCK);
 #else
 	int client = accept(w->fd, (struct sockaddr *) &addr, &sl);
 #endif
@@ -2760,26 +2760,18 @@ daemonize()
 		exit(0);
 	}
 
-	/* close standard streams */
-	fclose(stdin);
-	fclose(stdout);
-	fclose(stderr);
-
 	/* reopen standard streams to null device */
-	stdin = fopen(NULL_DEV, "r");
-	if (stdin == NULL) {
+	if (freopen(NULL_DEV, "r", stdin) == NULL) {
 		ERR("Unable to reopen stdin to %s: %s\n",
 		    NULL_DEV, strerror(errno));
 		exit(1);
 	}
-	stdout = fopen(NULL_DEV, "w");
-	if (stdout == NULL) {
+	if (freopen(NULL_DEV, "w", stdout) == NULL) {
 		ERR("Unable to reopen stdout to %s: %s\n",
 		    NULL_DEV, strerror(errno));
 		exit(1);
 	}
-	stderr = fopen(NULL_DEV, "w");
-	if (stderr == NULL) {
+	if (freopen(NULL_DEV, "w", stderr) == NULL) {
 		ERR("Unable to reopen stderr to %s: %s\n",
 		    NULL_DEV, strerror(errno));
 		exit(1);
@@ -2996,7 +2988,7 @@ cert_commit(struct cfg_tpc_obj *o)
 		insert_sni_names(sc);
 		break;
 	case CFG_TPC_KEEP:
-		assert(0);
+		WRONG("unreachable");
 		break;
 	case CFG_TPC_DROP:
 		HASH_DEL(ssl_ctxs, sc);
@@ -3030,7 +3022,7 @@ dcert_commit(struct cfg_tpc_obj *o)
 	case CFG_TPC_DROP:
 		/* We always have a default cert. This should not
 		 * happen. */
-		assert(0);
+		WRONG("unreachable");
 		break;
 	}
 }
@@ -3041,7 +3033,7 @@ cert_query(hitch_config *cfg, struct cfg_tpc_obj_head *cfg_objs)
 {
 	struct cfg_cert_file *cf, *cftmp;
 	sslctx *sc, *sctmp;
-	struct cfg_tpc_obj *o;
+	struct cfg_tpc_obj *o, *otmp;
 	struct listen_sock *ls;
 
 	/* NB: The ordering here is significant. It is imperative that
@@ -3061,7 +3053,7 @@ cert_query(hitch_config *cfg, struct cfg_tpc_obj_head *cfg_objs)
 
 	/* handle default cert. Default cert has its own
 	 * rollback/commit functions. */
-	assert(cfg->CERT_DEFAULT != NULL);
+	AN(cfg->CERT_DEFAULT);
 	cf = cfg->CERT_DEFAULT;
 	CHECK_OBJ_NOTNULL(default_ctx, SSLCTX_MAGIC);
 	if (strcmp(default_ctx->filename, cf->filename) != 0
@@ -3109,7 +3101,6 @@ cert_query(hitch_config *cfg, struct cfg_tpc_obj_head *cfg_objs)
 		HASH_FIND_STR(cfg->CERT_FILES, ls->cert->filename, cf);
 		if (cf != NULL) {
 			CAST_OBJ_NOTNULL(sc, cf->priv, SSLCTX_MAGIC);
-			o->p[1] = sc;
 		} else {
 			sc = make_ctx(ls->cert);
 			if (sc == NULL)
@@ -3118,11 +3109,11 @@ cert_query(hitch_config *cfg, struct cfg_tpc_obj_head *cfg_objs)
 				sctx_free(sc, NULL);
 				return (-1);
 			}
-			o = make_cfg_obj(CFG_CERT, CFG_TPC_NEW,
+			otmp = make_cfg_obj(CFG_CERT, CFG_TPC_NEW,
 			    sc, cert_rollback, cert_commit);
-			VTAILQ_INSERT_TAIL(cfg_objs, o, list);
-			o->p[1] = sc;
+			VTAILQ_INSERT_TAIL(cfg_objs, otmp, list);
 		}
+		o->p[1] = sc;
 	}
 	return (0);
 }
